@@ -1,10 +1,8 @@
 #include "TestResult.h"
 
-void TestResult_result(TestResultRef self,TestListnerRef listner)
+void TestResult_init(TestResultRef self,TestListnerRef listner)
 {
-	self->startTest = TestResult_startTest;
-	self->endTest = TestResult_endTest;
-	self->addFailure = TestResult_addFailure;
+	self->isa = (TestListnerImplementRef)&TestResultImplement;
 	self->numberOfTestsRun = 0;
 	self->numberOfFailures = 0;
 	self->listener = listner;
@@ -14,14 +12,14 @@ void TestResult_startTest(TestResultRef self,TestRef test)
 {
 	self->numberOfTestsRun++;
 	if (self->listener) {
-		self->listener->startTest(self->listener, test);
+		TestListner_startTest(self->listener, test);
 	}
 }
 
 void TestResult_endTest(TestResultRef self,TestRef test)
 {
 	if (self->listener) {
-		self->listener->endTest(self->listener, test);
+		TestListner_endTest(self->listener, test);
 	}
 }
 
@@ -29,6 +27,12 @@ void TestResult_addFailure(TestResultRef self,TestRef test,char *msg,int line,ch
 {
 	self->numberOfFailures++;
 	if (self->listener) {
-		self->listener->addFailure(self->listener, test, msg, line, file);
+		TestListner_addFailure(self->listener, test, msg, line, file);
 	}
 }
+
+const TestListnerImplement TestResultImplement = {
+	(TestListnerImplStartTest)TestResult_startTest,
+	(TestListnerImplEndTest)TestResult_endTest,
+	(TestListnerImplAddFailure)TestResult_addFailure,
+};
\ No newline at end of file
