@@ -3,12 +3,12 @@
 #include "TestResult.h"
 #include "TestRunner.h"
 
-static TestResult _result;
+static TestResult result_;
 
 void TestRunner_startTest(TestListnerRef self,TestRef test)
 {
 	stdimpl_puts("\t");
-	stdimpl_puts(test->name);
+	stdimpl_puts(Test_name(test));
 	stdimpl_puts("\n");
 }
 
@@ -29,44 +29,48 @@ void TestRunner_addFailure(TestListnerRef self,TestRef test,char *msg,int line,c
 	stdimpl_puts("\n");
 }
 
-const TestListner _listner = {
-	TestRunner_startTest,
-	TestRunner_endTest,
-	TestRunner_addFailure,
+static const TestListnerImplement TestRunnerImplement = {
+	(TestListnerImplStartTest)TestRunner_startTest,
+	(TestListnerImplEndTest)TestRunner_endTest,
+	(TestListnerImplAddFailure)TestRunner_addFailure,
+};
+
+static const TestRunner runner_ = {
+	(TestListnerImplementRef)&TestRunnerImplement,
 };
 
 void TestRunner_init(void)
 {
-	TestResult_result(&_result, (TestListnerRef)&_listner);
+	TestResult_init(&result_, (TestListnerRef)&runner_);
 }
 
 void TestRunner_runt(TestRef test)
 {
-	stdimpl_puts(test->name);
+	stdimpl_puts(Test_name(test));
 	stdimpl_puts(" :\n");
-	test->run(test, &_result);
+	Test_run(test, &result_);
 }
 
 TestResultRef TestRunner_result(void)
 {
-	return (TestResultRef)&_result;
+	return (TestResultRef)&result_;
 }
 
 void TestRunner_printResult(void)
 {
-	if (_result.numberOfFailures) {
+	if (result_.numberOfFailures) {
 		char buf[34];
 		stdimpl_puts("\nrun ");
-		stdimpl_itoa(_result.numberOfTestsRun, buf, 10);
+		stdimpl_itoa(result_.numberOfTestsRun, buf, 10);
 		stdimpl_puts(buf);
 		stdimpl_puts(" failures ");
-		stdimpl_itoa(_result.numberOfFailures, buf, 10);
+		stdimpl_itoa(result_.numberOfFailures, buf, 10);
 		stdimpl_puts(buf);
 		stdimpl_puts("\n");
 	} else {
 		char buf[34];
 		stdimpl_puts("\nOK (");
-		stdimpl_itoa(_result.numberOfTestsRun, buf, 10);
+		stdimpl_itoa(result_.numberOfTestsRun, buf, 10);
 		stdimpl_puts(buf);
 		stdimpl_puts(" tests)\n");
 	}
